@@ -1,3 +1,14 @@
+#' @describeIn logret Log returns of vectors
+#' @family utilities
+#' @export
+
+logret.default <- function(dat, demean = FALSE, standardize = FALSE, ...) {
+  logretx <- tail(diff(log(dat)), length(dat) - 1)
+  if (all(isTRUE(demean))) logretx <- logretx - mean(logretx)
+  if (all(isTRUE(standardize))) logretx <- logretx / sd(logretx)
+  logretx
+}
+
 myplot <- function (X) {
   par(mfrow = c(4, 1))
   for (i in 1:4) {
