@@ -1,25 +1,3 @@
-#' Computes (de-meaned) log returns.
-#' 
-#' Small utlity function returning either \code{diff(log(x))} in case the
-#' argument \code{demean} is set to \code{FALSE}, or \code{diff(log(x)) -
-#' mean(diff(log(x)))} in case that \code{demean} is \code{TRUE}.
-#' 
-#' 
-#' @param x Real-valued vector.
-#' @param demean A single logical value indicating whether the returns should
-#' be de-meaned. Defaults to \code{FALSE}.
-#' @return A vector of length \code{length(x) - 1}, containing (de-meaned)
-#' returns.
-#' @author Gregor Kastner \email{gregor.kastner@@wu.ac.at}
-#' @keywords utilities
-#' @export
-logret <- function(x, demean = FALSE) {
-  logretx <- tail(diff(log(x)), length(x)-1)
-  if (isTRUE(demean)) logretx <- logretx - mean(logretx)
-  logretx
-}
-
-
 #' @rdname extractors
 #' @export
 para <- function(x) {
